# Analyzer

The `Analyzer` class is part of the `jarvais.analyzer` module. It provides tools for exploring datasets and identifying issues.

::: jarvais.analyzer.Analyzer
    options:
        heading_level: 3
        members_order: source
        show_root_heading: true
            